from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast_active_multicast_enabled import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast_fec_info import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast:
    """
    Attributes:
        enabled (Union[Unset, str]):
        user_trigger_threshold (Union[Unset, str]):
        dest_ip_address (Union[Unset, str]):
        video_dest_port_no (Union[Unset, str]):
        audio_dest_port_no (Union[Unset, str]):
        dest_i_pv_6_address (Union[Unset, str]):
        ttl (Union[Unset, str]):
        active_multicast_enabled (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled]):
        packaging_format (Union[Unset, str]):
        fec_info (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo]):
    """

    enabled: Union[Unset, str] = UNSET
    user_trigger_threshold: Union[Unset, str] = UNSET
    dest_ip_address: Union[Unset, str] = UNSET
    video_dest_port_no: Union[Unset, str] = UNSET
    audio_dest_port_no: Union[Unset, str] = UNSET
    dest_i_pv_6_address: Union[Unset, str] = UNSET
    ttl: Union[Unset, str] = UNSET
    active_multicast_enabled: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled"
    ] = UNSET
    packaging_format: Union[Unset, str] = UNSET
    fec_info: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        user_trigger_threshold = self.user_trigger_threshold
        dest_ip_address = self.dest_ip_address
        video_dest_port_no = self.video_dest_port_no
        audio_dest_port_no = self.audio_dest_port_no
        dest_i_pv_6_address = self.dest_i_pv_6_address
        ttl = self.ttl
        active_multicast_enabled: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.active_multicast_enabled, Unset):
            active_multicast_enabled = self.active_multicast_enabled.to_dict()

        packaging_format = self.packaging_format
        fec_info: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fec_info, Unset):
            fec_info = self.fec_info.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if user_trigger_threshold is not UNSET:
            field_dict["userTriggerThreshold"] = user_trigger_threshold
        if dest_ip_address is not UNSET:
            field_dict["destIPAddress"] = dest_ip_address
        if video_dest_port_no is not UNSET:
            field_dict["videoDestPortNo"] = video_dest_port_no
        if audio_dest_port_no is not UNSET:
            field_dict["audioDestPortNo"] = audio_dest_port_no
        if dest_i_pv_6_address is not UNSET:
            field_dict["destIPv6Address"] = dest_i_pv_6_address
        if ttl is not UNSET:
            field_dict["ttl"] = ttl
        if active_multicast_enabled is not UNSET:
            field_dict["activeMulticastEnabled"] = active_multicast_enabled
        if packaging_format is not UNSET:
            field_dict["packagingFormat"] = packaging_format
        if fec_info is not UNSET:
            field_dict["FecInfo"] = fec_info

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast_active_multicast_enabled import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast_fec_info import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        user_trigger_threshold = d.pop("userTriggerThreshold", UNSET)

        dest_ip_address = d.pop("destIPAddress", UNSET)

        video_dest_port_no = d.pop("videoDestPortNo", UNSET)

        audio_dest_port_no = d.pop("audioDestPortNo", UNSET)

        dest_i_pv_6_address = d.pop("destIPv6Address", UNSET)

        ttl = d.pop("ttl", UNSET)

        _active_multicast_enabled = d.pop("activeMulticastEnabled", UNSET)
        active_multicast_enabled: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled
        ]
        if isinstance(_active_multicast_enabled, Unset):
            active_multicast_enabled = UNSET
        else:
            active_multicast_enabled = (
                RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastActiveMulticastEnabled.from_dict(
                    _active_multicast_enabled
                )
            )

        packaging_format = d.pop("packagingFormat", UNSET)

        _fec_info = d.pop("FecInfo", UNSET)
        fec_info: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo]
        if isinstance(_fec_info, Unset):
            fec_info = UNSET
        else:
            fec_info = RootTypeForXMLStreamingChannelStreamingChannelTransportMulticastFecInfo.from_dict(_fec_info)

        root_type_for_xml_streaming_channel_streaming_channel_transport_multicast = cls(
            enabled=enabled,
            user_trigger_threshold=user_trigger_threshold,
            dest_ip_address=dest_ip_address,
            video_dest_port_no=video_dest_port_no,
            audio_dest_port_no=audio_dest_port_no,
            dest_i_pv_6_address=dest_i_pv_6_address,
            ttl=ttl,
            active_multicast_enabled=active_multicast_enabled,
            packaging_format=packaging_format,
            fec_info=fec_info,
        )

        root_type_for_xml_streaming_channel_streaming_channel_transport_multicast.additional_properties = d
        return root_type_for_xml_streaming_channel_streaming_channel_transport_multicast

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel import (
        RootTypeForXMLStreamingChannelStreamingChannel,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannel:
    """StreamingChannel message in XML format

    Example:
        {'StreamingChannel': {'id': '', 'channelName': '', 'enabled': '', 'Transport': {'maxPacketSize': '',
            'audioPacketLength': '', 'audioInboundPacketLength': '', 'audioInboundPortNo': '', 'videoSourcePortNo': '',
            'audioSourcePortNo': '', 'ControlProtocolList': {'ControlProtocol': {'streamingTransport': {}}}, 'Unicast':
            {'enabled': '', 'interfaceID': '', 'rtpTransportType': {}}, 'Multicast': {'enabled': '', 'userTriggerThreshold':
            '', 'destIPAddress': '', 'videoDestPortNo': '', 'audioDestPortNo': '', 'destIPv6Address': '', 'ttl': '',
            'activeMulticastEnabled': {}, 'packagingFormat': '', 'FecInfo': {'fecRatio': {}, 'fecDestPortNo': {}}},
            'Security': {'enabled': '', 'certificateType': '', 'SecurityAlgorithm': {'algorithmType': ''}}, 'SRTPMulticast':
            {'SRTPVideoDestPortNo': '', 'SRTPAudioDestPortNo': ''}}, 'Video': {'enabled': '', 'videoInputChannelID': {},
            'videoCodecType': {}, 'videoResolutionWidth': {}, 'videoResolutionHeight': {}, 'videoQualityControlType': {},
            'constantBitRate': {}, 'vbrUpperCap': {}, 'vbrLowerCap': {}, 'maxFrameRate': {}, 'keyFrameInterval': '',
            'rotationDegree': '', 'mirrorEnabled': '', 'snapShotImageType': '', 'Mpeg4Profile': '', 'H264Profile': '',
            'SVACProfile': '', 'GovLength': '', 'SVC': {'enabled': '', 'SVCMode': ''}, 'smoothing': '', 'SmartCodec':
            {'enabled': ''}, 'vbrAverageCap': '', 'IntelligentInfoDisplayMethod': {}}, 'Audio': {'enabled': '',
            'audioInputChannelID': '', 'audioCompressionType': {}, 'audioInboundCompressionType': {}, 'audioBitRate': '',
            'audioSamplingRate': '', 'audioResolution': '', 'VoiceChanger': {'enabled': '', 'level': ''}}, 'enableCABAC':
            '', 'subStreamRecStatus': '', 'customStreamEnable': {'StreamingChannel': {'id': '', 'channelName': '',
            'enabled': '', 'Transport': {'maxPacketSize': '', 'audioPacketLength': '', 'audioInboundPacketLength': '',
            'audioInboundPortNo': '', 'videoSourcePortNo': '', 'audioSourcePortNo': '', 'ControlProtocolList':
            {'ControlProtocol': {'streamingTransport': {}}}, 'Unicast': {'enabled': '', 'interfaceID': '',
            'rtpTransportType': {}}, 'Multicast': {'enabled': '', 'userTriggerThreshold': '', 'destIPAddress': '',
            'videoDestPortNo': '', 'audioDestPortNo': '', 'destIPv6Address': '', 'ttl': '', 'activeMulticastEnabled': {},
            'packagingFormat': '', 'FecInfo': {'fecRatio': {}, 'fecDestPortNo': {}}}, 'Security': {'enabled': '',
            'certificateType': '', 'SecurityAlgorithm': {'algorithmType': ''}}, 'SRTPMulticast': {'SRTPVideoDestPortNo': '',
            'SRTPAudioDestPortNo': ''}}, 'Video': {'enabled': '', 'videoInputChannelID': {}, 'videoCodecType': {},
            'videoResolutionWidth': {}, 'videoResolutionHeight': {}, 'videoQualityControlType': {}, 'constantBitRate': {},
            'vbrUpperCap': {}, 'vbrLowerCap': {}, 'maxFrameRate': {}, 'keyFrameInterval': '', 'rotationDegree': '',
            'mirrorEnabled': '', 'snapShotImageType': '', 'Mpeg4Profile': '', 'H264Profile': '', 'SVACProfile': '',
            'GovLength': '', 'SVC': {'enabled': '', 'SVCMode': ''}, 'smoothing': '', 'SmartCodec': {'enabled': ''},
            'vbrAverageCap': '', 'IntelligentInfoDisplayMethod': {}}, 'Audio': {'enabled': '', 'audioInputChannelID': '',
            'audioCompressionType': {}, 'audioInboundCompressionType': {}, 'audioBitRate': '', 'audioSamplingRate': '',
            'audioResolution': '', 'VoiceChanger': {'enabled': '', 'level': ''}}, 'enableCABAC': '', 'subStreamRecStatus':
            '', 'customStreamEnable': '', '@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}, '@version':
            '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}

    Attributes:
        streaming_channel (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannel]):
    """

    streaming_channel: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannel"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        streaming_channel: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.streaming_channel, Unset):
            streaming_channel = self.streaming_channel.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if streaming_channel is not UNSET:
            field_dict["StreamingChannel"] = streaming_channel

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel import (
            RootTypeForXMLStreamingChannelStreamingChannel,
        )

        d = src_dict.copy()
        _streaming_channel = d.pop("StreamingChannel", UNSET)
        streaming_channel: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannel]
        if isinstance(_streaming_channel, Unset):
            streaming_channel = UNSET
        else:
            streaming_channel = RootTypeForXMLStreamingChannelStreamingChannel.from_dict(_streaming_channel)

        root_type_for_xml_streaming_channel = cls(
            streaming_channel=streaming_channel,
        )

        root_type_for_xml_streaming_channel.additional_properties = d
        return root_type_for_xml_streaming_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx
import xmltodict

from ... import errors
from ...client import Client
from ...models.root_type_for_xml_response_status_authentication_failed import (
    RootTypeForXMLResponseStatusAuthenticationFailed,
)
from ...models.root_type_for_xml_session_login import RootTypeForXMLSessionLogin
from ...models.root_type_for_xml_session_login_response import RootTypeForXMLSessionLoginResponse
from ...types import UNSET, Response


def _get_kwargs(
    *,
    client: Client,
    json_body: RootTypeForXMLSessionLogin,
    time_stamp: float,
) -> Dict[str, Any]:
    url = "{}/ISAPI/Security/sessionLogin".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["timeStamp"] = time_stamp

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "data": xmltodict.unparse(json_json_body),
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = RootTypeForXMLSessionLoginResponse.from_dict(xmltodict.parse(response.text))

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = RootTypeForXMLResponseStatusAuthenticationFailed.from_dict(xmltodict.parse(response.text))

        return response_401
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: RootTypeForXMLSessionLogin,
    time_stamp: float,
) -> Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    """sessionLogin

     sessionLogin

    Args:
        time_stamp (float):
        json_body (RootTypeForXMLSessionLogin):  Example: {'SessionLogin': {'userName': 'admin',
            'password': 'xxxxxxxxxxxx', 'sessionID':
            '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f', 'isSupportSessionTag':
            'false', 'isSessionIDValidLongTerm': 'false', 'sessionIDVersion': '2', '@version': '2.0',
            '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        time_stamp=time_stamp,
    )

    response = client._api.request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: Client,
    json_body: RootTypeForXMLSessionLogin,
    time_stamp: float,
) -> Optional[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    """sessionLogin

     sessionLogin

    Args:
        time_stamp (float):
        json_body (RootTypeForXMLSessionLogin):  Example: {'SessionLogin': {'userName': 'admin',
            'password': 'xxxxxxxxxxxx', 'sessionID':
            '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f', 'isSupportSessionTag':
            'false', 'isSessionIDValidLongTerm': 'false', 'sessionIDVersion': '2', '@version': '2.0',
            '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
        time_stamp=time_stamp,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: RootTypeForXMLSessionLogin,
    time_stamp: float,
) -> Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    """sessionLogin

     sessionLogin

    Args:
        time_stamp (float):
        json_body (RootTypeForXMLSessionLogin):  Example: {'SessionLogin': {'userName': 'admin',
            'password': 'xxxxxxxxxxxx', 'sessionID':
            '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f', 'isSupportSessionTag':
            'false', 'isSessionIDValidLongTerm': 'false', 'sessionIDVersion': '2', '@version': '2.0',
            '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
        time_stamp=time_stamp,
    )

    response = await client._asyncio_api.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: Client,
    json_body: RootTypeForXMLSessionLogin,
    time_stamp: float,
) -> Optional[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]:
    """sessionLogin

     sessionLogin

    Args:
        time_stamp (float):
        json_body (RootTypeForXMLSessionLogin):  Example: {'SessionLogin': {'userName': 'admin',
            'password': 'xxxxxxxxxxxx', 'sessionID':
            '5ab522a707187090e375dc9e07f80f48f6a2a1c4a171b501b47ea9607db57f7f', 'isSupportSessionTag':
            'false', 'isSessionIDValidLongTerm': 'false', 'sessionIDVersion': '2', '@version': '2.0',
            '@xmlns': 'http://www.isapi.org/ver20/XMLSchema'}}.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[RootTypeForXMLResponseStatusAuthenticationFailed, RootTypeForXMLSessionLoginResponse]]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
            time_stamp=time_stamp,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_audio_compression_type import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_audio_inbound_compression_type import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioInboundCompressionType,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_voice_changer import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio:
    """
    Attributes:
        enabled (Union[Unset, str]):
        audio_input_channel_id (Union[Unset, str]):
        audio_compression_type (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType]):
        audio_inbound_compression_type (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStr
            eamingChannelAudioAudioInboundCompressionType]):
        audio_bit_rate (Union[Unset, str]):
        audio_sampling_rate (Union[Unset, str]):
        audio_resolution (Union[Unset, str]):
        voice_changer (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger]):
    """

    enabled: Union[Unset, str] = UNSET
    audio_input_channel_id: Union[Unset, str] = UNSET
    audio_compression_type: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType",
    ] = UNSET
    audio_inbound_compression_type: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioInboundCompressionType",
    ] = UNSET
    audio_bit_rate: Union[Unset, str] = UNSET
    audio_sampling_rate: Union[Unset, str] = UNSET
    audio_resolution: Union[Unset, str] = UNSET
    voice_changer: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger"
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        audio_input_channel_id = self.audio_input_channel_id
        audio_compression_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_compression_type, Unset):
            audio_compression_type = self.audio_compression_type.to_dict()

        audio_inbound_compression_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio_inbound_compression_type, Unset):
            audio_inbound_compression_type = self.audio_inbound_compression_type.to_dict()

        audio_bit_rate = self.audio_bit_rate
        audio_sampling_rate = self.audio_sampling_rate
        audio_resolution = self.audio_resolution
        voice_changer: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.voice_changer, Unset):
            voice_changer = self.voice_changer.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if audio_input_channel_id is not UNSET:
            field_dict["audioInputChannelID"] = audio_input_channel_id
        if audio_compression_type is not UNSET:
            field_dict["audioCompressionType"] = audio_compression_type
        if audio_inbound_compression_type is not UNSET:
            field_dict["audioInboundCompressionType"] = audio_inbound_compression_type
        if audio_bit_rate is not UNSET:
            field_dict["audioBitRate"] = audio_bit_rate
        if audio_sampling_rate is not UNSET:
            field_dict["audioSamplingRate"] = audio_sampling_rate
        if audio_resolution is not UNSET:
            field_dict["audioResolution"] = audio_resolution
        if voice_changer is not UNSET:
            field_dict["VoiceChanger"] = voice_changer

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_audio_compression_type import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_audio_inbound_compression_type import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioInboundCompressionType,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio_voice_changer import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        audio_input_channel_id = d.pop("audioInputChannelID", UNSET)

        _audio_compression_type = d.pop("audioCompressionType", UNSET)
        audio_compression_type: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType,
        ]
        if isinstance(_audio_compression_type, Unset):
            audio_compression_type = UNSET
        else:
            audio_compression_type = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioCompressionType.from_dict(
                _audio_compression_type
            )

        _audio_inbound_compression_type = d.pop("audioInboundCompressionType", UNSET)
        audio_inbound_compression_type: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioInboundCompressionType,
        ]
        if isinstance(_audio_inbound_compression_type, Unset):
            audio_inbound_compression_type = UNSET
        else:
            audio_inbound_compression_type = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioAudioInboundCompressionType.from_dict(
                _audio_inbound_compression_type
            )

        audio_bit_rate = d.pop("audioBitRate", UNSET)

        audio_sampling_rate = d.pop("audioSamplingRate", UNSET)

        audio_resolution = d.pop("audioResolution", UNSET)

        _voice_changer = d.pop("VoiceChanger", UNSET)
        voice_changer: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger
        ]
        if isinstance(_voice_changer, Unset):
            voice_changer = UNSET
        else:
            voice_changer = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudioVoiceChanger.from_dict(
                _voice_changer
            )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio = cls(
            enabled=enabled,
            audio_input_channel_id=audio_input_channel_id,
            audio_compression_type=audio_compression_type,
            audio_inbound_compression_type=audio_inbound_compression_type,
            audio_bit_rate=audio_bit_rate,
            audio_sampling_rate=audio_sampling_rate,
            audio_resolution=audio_resolution,
            voice_changer=voice_changer,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_constant_bit_rate import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_intelligent_info_display_method import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoIntelligentInfoDisplayMethod,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_max_frame_rate import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_smart_codec import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_svc import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_vbr_lower_cap import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_vbr_upper_cap import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_codec_type import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_input_channel_id import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_quality_control_type import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_resolution_height import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_resolution_width import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo:
    """
    Attributes:
        enabled (Union[Unset, str]):
        video_input_channel_id (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID]):
        video_codec_type (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType]):
        video_resolution_width (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth]):
        video_resolution_height (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight]):
        video_quality_control_type (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType]):
        constant_bit_rate (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate]):
        vbr_upper_cap (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap]):
        vbr_lower_cap (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap]):
        max_frame_rate (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate]):
        key_frame_interval (Union[Unset, str]):
        rotation_degree (Union[Unset, str]):
        mirror_enabled (Union[Unset, str]):
        snap_shot_image_type (Union[Unset, str]):
        mpeg_4_profile (Union[Unset, str]):
        h264_profile (Union[Unset, str]):
        svac_profile (Union[Unset, str]):
        gov_length (Union[Unset, str]):
        svc (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC]):
        smoothing (Union[Unset, str]):
        smart_codec (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec]):
        vbr_average_cap (Union[Unset, str]):
        intelligent_info_display_method (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableSt
            reamingChannelVideoIntelligentInfoDisplayMethod]):
    """

    enabled: Union[Unset, str] = UNSET
    video_input_channel_id: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID",
    ] = UNSET
    video_codec_type: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType"
    ] = UNSET
    video_resolution_width: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth",
    ] = UNSET
    video_resolution_height: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight",
    ] = UNSET
    video_quality_control_type: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType",
    ] = UNSET
    constant_bit_rate: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate"
    ] = UNSET
    vbr_upper_cap: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap"
    ] = UNSET
    vbr_lower_cap: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap"
    ] = UNSET
    max_frame_rate: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate"
    ] = UNSET
    key_frame_interval: Union[Unset, str] = UNSET
    rotation_degree: Union[Unset, str] = UNSET
    mirror_enabled: Union[Unset, str] = UNSET
    snap_shot_image_type: Union[Unset, str] = UNSET
    mpeg_4_profile: Union[Unset, str] = UNSET
    h264_profile: Union[Unset, str] = UNSET
    svac_profile: Union[Unset, str] = UNSET
    gov_length: Union[Unset, str] = UNSET
    svc: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC"
    ] = UNSET
    smoothing: Union[Unset, str] = UNSET
    smart_codec: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec"
    ] = UNSET
    vbr_average_cap: Union[Unset, str] = UNSET
    intelligent_info_display_method: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoIntelligentInfoDisplayMethod",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        video_input_channel_id: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_input_channel_id, Unset):
            video_input_channel_id = self.video_input_channel_id.to_dict()

        video_codec_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_codec_type, Unset):
            video_codec_type = self.video_codec_type.to_dict()

        video_resolution_width: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_resolution_width, Unset):
            video_resolution_width = self.video_resolution_width.to_dict()

        video_resolution_height: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_resolution_height, Unset):
            video_resolution_height = self.video_resolution_height.to_dict()

        video_quality_control_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video_quality_control_type, Unset):
            video_quality_control_type = self.video_quality_control_type.to_dict()

        constant_bit_rate: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.constant_bit_rate, Unset):
            constant_bit_rate = self.constant_bit_rate.to_dict()

        vbr_upper_cap: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.vbr_upper_cap, Unset):
            vbr_upper_cap = self.vbr_upper_cap.to_dict()

        vbr_lower_cap: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.vbr_lower_cap, Unset):
            vbr_lower_cap = self.vbr_lower_cap.to_dict()

        max_frame_rate: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.max_frame_rate, Unset):
            max_frame_rate = self.max_frame_rate.to_dict()

        key_frame_interval = self.key_frame_interval
        rotation_degree = self.rotation_degree
        mirror_enabled = self.mirror_enabled
        snap_shot_image_type = self.snap_shot_image_type
        mpeg_4_profile = self.mpeg_4_profile
        h264_profile = self.h264_profile
        svac_profile = self.svac_profile
        gov_length = self.gov_length
        svc: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.svc, Unset):
            svc = self.svc.to_dict()

        smoothing = self.smoothing
        smart_codec: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.smart_codec, Unset):
            smart_codec = self.smart_codec.to_dict()

        vbr_average_cap = self.vbr_average_cap
        intelligent_info_display_method: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.intelligent_info_display_method, Unset):
            intelligent_info_display_method = self.intelligent_info_display_method.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if video_input_channel_id is not UNSET:
            field_dict["videoInputChannelID"] = video_input_channel_id
        if video_codec_type is not UNSET:
            field_dict["videoCodecType"] = video_codec_type
        if video_resolution_width is not UNSET:
            field_dict["videoResolutionWidth"] = video_resolution_width
        if video_resolution_height is not UNSET:
            field_dict["videoResolutionHeight"] = video_resolution_height
        if video_quality_control_type is not UNSET:
            field_dict["videoQualityControlType"] = video_quality_control_type
        if constant_bit_rate is not UNSET:
            field_dict["constantBitRate"] = constant_bit_rate
        if vbr_upper_cap is not UNSET:
            field_dict["vbrUpperCap"] = vbr_upper_cap
        if vbr_lower_cap is not UNSET:
            field_dict["vbrLowerCap"] = vbr_lower_cap
        if max_frame_rate is not UNSET:
            field_dict["maxFrameRate"] = max_frame_rate
        if key_frame_interval is not UNSET:
            field_dict["keyFrameInterval"] = key_frame_interval
        if rotation_degree is not UNSET:
            field_dict["rotationDegree"] = rotation_degree
        if mirror_enabled is not UNSET:
            field_dict["mirrorEnabled"] = mirror_enabled
        if snap_shot_image_type is not UNSET:
            field_dict["snapShotImageType"] = snap_shot_image_type
        if mpeg_4_profile is not UNSET:
            field_dict["Mpeg4Profile"] = mpeg_4_profile
        if h264_profile is not UNSET:
            field_dict["H264Profile"] = h264_profile
        if svac_profile is not UNSET:
            field_dict["SVACProfile"] = svac_profile
        if gov_length is not UNSET:
            field_dict["GovLength"] = gov_length
        if svc is not UNSET:
            field_dict["SVC"] = svc
        if smoothing is not UNSET:
            field_dict["smoothing"] = smoothing
        if smart_codec is not UNSET:
            field_dict["SmartCodec"] = smart_codec
        if vbr_average_cap is not UNSET:
            field_dict["vbrAverageCap"] = vbr_average_cap
        if intelligent_info_display_method is not UNSET:
            field_dict["IntelligentInfoDisplayMethod"] = intelligent_info_display_method

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_constant_bit_rate import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_intelligent_info_display_method import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoIntelligentInfoDisplayMethod,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_max_frame_rate import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_smart_codec import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_svc import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_vbr_lower_cap import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_vbr_upper_cap import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_codec_type import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_input_channel_id import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_quality_control_type import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_resolution_height import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video_video_resolution_width import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        _video_input_channel_id = d.pop("videoInputChannelID", UNSET)
        video_input_channel_id: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID,
        ]
        if isinstance(_video_input_channel_id, Unset):
            video_input_channel_id = UNSET
        else:
            video_input_channel_id = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoInputChannelID.from_dict(
                _video_input_channel_id
            )

        _video_codec_type = d.pop("videoCodecType", UNSET)
        video_codec_type: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType
        ]
        if isinstance(_video_codec_type, Unset):
            video_codec_type = UNSET
        else:
            video_codec_type = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoCodecType.from_dict(
                _video_codec_type
            )

        _video_resolution_width = d.pop("videoResolutionWidth", UNSET)
        video_resolution_width: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth,
        ]
        if isinstance(_video_resolution_width, Unset):
            video_resolution_width = UNSET
        else:
            video_resolution_width = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionWidth.from_dict(
                _video_resolution_width
            )

        _video_resolution_height = d.pop("videoResolutionHeight", UNSET)
        video_resolution_height: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight,
        ]
        if isinstance(_video_resolution_height, Unset):
            video_resolution_height = UNSET
        else:
            video_resolution_height = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoResolutionHeight.from_dict(
                _video_resolution_height
            )

        _video_quality_control_type = d.pop("videoQualityControlType", UNSET)
        video_quality_control_type: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType,
        ]
        if isinstance(_video_quality_control_type, Unset):
            video_quality_control_type = UNSET
        else:
            video_quality_control_type = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVideoQualityControlType.from_dict(
                _video_quality_control_type
            )

        _constant_bit_rate = d.pop("constantBitRate", UNSET)
        constant_bit_rate: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate
        ]
        if isinstance(_constant_bit_rate, Unset):
            constant_bit_rate = UNSET
        else:
            constant_bit_rate = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoConstantBitRate.from_dict(
                _constant_bit_rate
            )

        _vbr_upper_cap = d.pop("vbrUpperCap", UNSET)
        vbr_upper_cap: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap
        ]
        if isinstance(_vbr_upper_cap, Unset):
            vbr_upper_cap = UNSET
        else:
            vbr_upper_cap = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrUpperCap.from_dict(
                _vbr_upper_cap
            )

        _vbr_lower_cap = d.pop("vbrLowerCap", UNSET)
        vbr_lower_cap: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap
        ]
        if isinstance(_vbr_lower_cap, Unset):
            vbr_lower_cap = UNSET
        else:
            vbr_lower_cap = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoVbrLowerCap.from_dict(
                _vbr_lower_cap
            )

        _max_frame_rate = d.pop("maxFrameRate", UNSET)
        max_frame_rate: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate
        ]
        if isinstance(_max_frame_rate, Unset):
            max_frame_rate = UNSET
        else:
            max_frame_rate = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoMaxFrameRate.from_dict(
                _max_frame_rate
            )

        key_frame_interval = d.pop("keyFrameInterval", UNSET)

        rotation_degree = d.pop("rotationDegree", UNSET)

        mirror_enabled = d.pop("mirrorEnabled", UNSET)

        snap_shot_image_type = d.pop("snapShotImageType", UNSET)

        mpeg_4_profile = d.pop("Mpeg4Profile", UNSET)

        h264_profile = d.pop("H264Profile", UNSET)

        svac_profile = d.pop("SVACProfile", UNSET)

        gov_length = d.pop("GovLength", UNSET)

        _svc = d.pop("SVC", UNSET)
        svc: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC]
        if isinstance(_svc, Unset):
            svc = UNSET
        else:
            svc = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSVC.from_dict(
                _svc
            )

        smoothing = d.pop("smoothing", UNSET)

        _smart_codec = d.pop("SmartCodec", UNSET)
        smart_codec: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec
        ]
        if isinstance(_smart_codec, Unset):
            smart_codec = UNSET
        else:
            smart_codec = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoSmartCodec.from_dict(
                _smart_codec
            )

        vbr_average_cap = d.pop("vbrAverageCap", UNSET)

        _intelligent_info_display_method = d.pop("IntelligentInfoDisplayMethod", UNSET)
        intelligent_info_display_method: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoIntelligentInfoDisplayMethod,
        ]
        if isinstance(_intelligent_info_display_method, Unset):
            intelligent_info_display_method = UNSET
        else:
            intelligent_info_display_method = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideoIntelligentInfoDisplayMethod.from_dict(
                _intelligent_info_display_method
            )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video = cls(
            enabled=enabled,
            video_input_channel_id=video_input_channel_id,
            video_codec_type=video_codec_type,
            video_resolution_width=video_resolution_width,
            video_resolution_height=video_resolution_height,
            video_quality_control_type=video_quality_control_type,
            constant_bit_rate=constant_bit_rate,
            vbr_upper_cap=vbr_upper_cap,
            vbr_lower_cap=vbr_lower_cap,
            max_frame_rate=max_frame_rate,
            key_frame_interval=key_frame_interval,
            rotation_degree=rotation_degree,
            mirror_enabled=mirror_enabled,
            snap_shot_image_type=snap_shot_image_type,
            mpeg_4_profile=mpeg_4_profile,
            h264_profile=h264_profile,
            svac_profile=svac_profile,
            gov_length=gov_length,
            svc=svc,
            smoothing=smoothing,
            smart_codec=smart_codec,
            vbr_average_cap=vbr_average_cap,
            intelligent_info_display_method=intelligent_info_display_method,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_unicast_rtp_transport_type import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicastRtpTransportType,
    )


T = TypeVar(
    "T", bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicast"
)


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicast:
    """
    Attributes:
        enabled (Union[Unset, str]):
        interface_id (Union[Unset, str]):
        rtp_transport_type (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChanne
            lTransportUnicastRtpTransportType]):
    """

    enabled: Union[Unset, str] = UNSET
    interface_id: Union[Unset, str] = UNSET
    rtp_transport_type: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicastRtpTransportType",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        interface_id = self.interface_id
        rtp_transport_type: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.rtp_transport_type, Unset):
            rtp_transport_type = self.rtp_transport_type.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if interface_id is not UNSET:
            field_dict["interfaceID"] = interface_id
        if rtp_transport_type is not UNSET:
            field_dict["rtpTransportType"] = rtp_transport_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_unicast_rtp_transport_type import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicastRtpTransportType,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        interface_id = d.pop("interfaceID", UNSET)

        _rtp_transport_type = d.pop("rtpTransportType", UNSET)
        rtp_transport_type: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicastRtpTransportType,
        ]
        if isinstance(_rtp_transport_type, Unset):
            rtp_transport_type = UNSET
        else:
            rtp_transport_type = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportUnicastRtpTransportType.from_dict(
                _rtp_transport_type
            )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_unicast = cls(
            enabled=enabled,
            interface_id=interface_id,
            rtp_transport_type=rtp_transport_type,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_unicast.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_unicast

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_security import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_srtp_multicast import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_unicast import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelTransport")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelTransport:
    """
    Attributes:
        max_packet_size (Union[Unset, str]):
        audio_packet_length (Union[Unset, str]):
        audio_inbound_packet_length (Union[Unset, str]):
        audio_inbound_port_no (Union[Unset, str]):
        video_source_port_no (Union[Unset, str]):
        audio_source_port_no (Union[Unset, str]):
        control_protocol_list (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList]):
        unicast (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast]):
        multicast (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast]):
        security (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity]):
        srtp_multicast (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast]):
    """

    max_packet_size: Union[Unset, str] = UNSET
    audio_packet_length: Union[Unset, str] = UNSET
    audio_inbound_packet_length: Union[Unset, str] = UNSET
    audio_inbound_port_no: Union[Unset, str] = UNSET
    video_source_port_no: Union[Unset, str] = UNSET
    audio_source_port_no: Union[Unset, str] = UNSET
    control_protocol_list: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList"
    ] = UNSET
    unicast: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast"] = UNSET
    multicast: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast"] = UNSET
    security: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity"] = UNSET
    srtp_multicast: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        max_packet_size = self.max_packet_size
        audio_packet_length = self.audio_packet_length
        audio_inbound_packet_length = self.audio_inbound_packet_length
        audio_inbound_port_no = self.audio_inbound_port_no
        video_source_port_no = self.video_source_port_no
        audio_source_port_no = self.audio_source_port_no
        control_protocol_list: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.control_protocol_list, Unset):
            control_protocol_list = self.control_protocol_list.to_dict()

        unicast: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.unicast, Unset):
            unicast = self.unicast.to_dict()

        multicast: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.multicast, Unset):
            multicast = self.multicast.to_dict()

        security: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.security, Unset):
            security = self.security.to_dict()

        srtp_multicast: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.srtp_multicast, Unset):
            srtp_multicast = self.srtp_multicast.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if max_packet_size is not UNSET:
            field_dict["maxPacketSize"] = max_packet_size
        if audio_packet_length is not UNSET:
            field_dict["audioPacketLength"] = audio_packet_length
        if audio_inbound_packet_length is not UNSET:
            field_dict["audioInboundPacketLength"] = audio_inbound_packet_length
        if audio_inbound_port_no is not UNSET:
            field_dict["audioInboundPortNo"] = audio_inbound_port_no
        if video_source_port_no is not UNSET:
            field_dict["videoSourcePortNo"] = video_source_port_no
        if audio_source_port_no is not UNSET:
            field_dict["audioSourcePortNo"] = audio_source_port_no
        if control_protocol_list is not UNSET:
            field_dict["ControlProtocolList"] = control_protocol_list
        if unicast is not UNSET:
            field_dict["Unicast"] = unicast
        if multicast is not UNSET:
            field_dict["Multicast"] = multicast
        if security is not UNSET:
            field_dict["Security"] = security
        if srtp_multicast is not UNSET:
            field_dict["SRTPMulticast"] = srtp_multicast

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_multicast import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_security import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_srtp_multicast import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_unicast import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast,
        )

        d = src_dict.copy()
        max_packet_size = d.pop("maxPacketSize", UNSET)

        audio_packet_length = d.pop("audioPacketLength", UNSET)

        audio_inbound_packet_length = d.pop("audioInboundPacketLength", UNSET)

        audio_inbound_port_no = d.pop("audioInboundPortNo", UNSET)

        video_source_port_no = d.pop("videoSourcePortNo", UNSET)

        audio_source_port_no = d.pop("audioSourcePortNo", UNSET)

        _control_protocol_list = d.pop("ControlProtocolList", UNSET)
        control_protocol_list: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList]
        if isinstance(_control_protocol_list, Unset):
            control_protocol_list = UNSET
        else:
            control_protocol_list = (
                RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolList.from_dict(
                    _control_protocol_list
                )
            )

        _unicast = d.pop("Unicast", UNSET)
        unicast: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast]
        if isinstance(_unicast, Unset):
            unicast = UNSET
        else:
            unicast = RootTypeForXMLStreamingChannelStreamingChannelTransportUnicast.from_dict(_unicast)

        _multicast = d.pop("Multicast", UNSET)
        multicast: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast]
        if isinstance(_multicast, Unset):
            multicast = UNSET
        else:
            multicast = RootTypeForXMLStreamingChannelStreamingChannelTransportMulticast.from_dict(_multicast)

        _security = d.pop("Security", UNSET)
        security: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity]
        if isinstance(_security, Unset):
            security = UNSET
        else:
            security = RootTypeForXMLStreamingChannelStreamingChannelTransportSecurity.from_dict(_security)

        _srtp_multicast = d.pop("SRTPMulticast", UNSET)
        srtp_multicast: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast]
        if isinstance(_srtp_multicast, Unset):
            srtp_multicast = UNSET
        else:
            srtp_multicast = RootTypeForXMLStreamingChannelStreamingChannelTransportSRTPMulticast.from_dict(
                _srtp_multicast
            )

        root_type_for_xml_streaming_channel_streaming_channel_transport = cls(
            max_packet_size=max_packet_size,
            audio_packet_length=audio_packet_length,
            audio_inbound_packet_length=audio_inbound_packet_length,
            audio_inbound_port_no=audio_inbound_port_no,
            video_source_port_no=video_source_port_no,
            audio_source_port_no=audio_source_port_no,
            control_protocol_list=control_protocol_list,
            unicast=unicast,
            multicast=multicast,
            security=security,
            srtp_multicast=srtp_multicast,
        )

        root_type_for_xml_streaming_channel_streaming_channel_transport.additional_properties = d
        return root_type_for_xml_streaming_channel_streaming_channel_transport

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_cmd import (
        RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd,
    )
    from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_door_no import (
        RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo,
    )
    from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_password import (
        RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword,
    )


T = TypeVar("T", bound="RootTypeForXMLCapRemoteControlDoorRemoteControlDoor")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapRemoteControlDoorRemoteControlDoor:
    """
    Attributes:
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
        door_no (Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo]):
        cmd (Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd]):
        password (Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword]):
    """

    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    door_no: Union[Unset, "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo"] = UNSET
    cmd: Union[Unset, "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd"] = UNSET
    password: Union[Unset, "RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        version = self.version
        xmlns = self.xmlns
        door_no: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.door_no, Unset):
            door_no = self.door_no.to_dict()

        cmd: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.cmd, Unset):
            cmd = self.cmd.to_dict()

        password: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.password, Unset):
            password = self.password.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns
        if door_no is not UNSET:
            field_dict["doorNo"] = door_no
        if cmd is not UNSET:
            field_dict["cmd"] = cmd
        if password is not UNSET:
            field_dict["password"] = password

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_cmd import (
            RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd,
        )
        from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_door_no import (
            RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo,
        )
        from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door_password import (
            RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword,
        )

        d = src_dict.copy()
        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        _door_no = d.pop("doorNo", UNSET)
        door_no: Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo]
        if isinstance(_door_no, Unset):
            door_no = UNSET
        else:
            door_no = RootTypeForXMLCapRemoteControlDoorRemoteControlDoorDoorNo.from_dict(_door_no)

        _cmd = d.pop("cmd", UNSET)
        cmd: Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd]
        if isinstance(_cmd, Unset):
            cmd = UNSET
        else:
            cmd = RootTypeForXMLCapRemoteControlDoorRemoteControlDoorCmd.from_dict(_cmd)

        _password = d.pop("password", UNSET)
        password: Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword]
        if isinstance(_password, Unset):
            password = UNSET
        else:
            password = RootTypeForXMLCapRemoteControlDoorRemoteControlDoorPassword.from_dict(_password)

        root_type_for_xml_cap_remote_control_door_remote_control_door = cls(
            version=version,
            xmlns=xmlns,
            door_no=door_no,
            cmd=cmd,
            password=password,
        )

        root_type_for_xml_cap_remote_control_door_remote_control_door.additional_properties = d
        return root_type_for_xml_cap_remote_control_door_remote_control_door

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannel")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannel:
    """
    Attributes:
        id (Union[Unset, str]):
        channel_name (Union[Unset, str]):
        enabled (Union[Unset, str]):
        transport (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport]):
        video (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo]):
        audio (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio]):
        enable_cabac (Union[Unset, str]):
        sub_stream_rec_status (Union[Unset, str]):
        custom_stream_enable (Union[Unset, str]):
        version (Union[Unset, str]):
        xmlns (Union[Unset, str]):
    """

    id: Union[Unset, str] = UNSET
    channel_name: Union[Unset, str] = UNSET
    enabled: Union[Unset, str] = UNSET
    transport: Union[
        Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport"
    ] = UNSET
    video: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo"] = UNSET
    audio: Union[Unset, "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio"] = UNSET
    enable_cabac: Union[Unset, str] = UNSET
    sub_stream_rec_status: Union[Unset, str] = UNSET
    custom_stream_enable: Union[Unset, str] = UNSET
    version: Union[Unset, str] = UNSET
    xmlns: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        channel_name = self.channel_name
        enabled = self.enabled
        transport: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.transport, Unset):
            transport = self.transport.to_dict()

        video: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.video, Unset):
            video = self.video.to_dict()

        audio: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.audio, Unset):
            audio = self.audio.to_dict()

        enable_cabac = self.enable_cabac
        sub_stream_rec_status = self.sub_stream_rec_status
        custom_stream_enable = self.custom_stream_enable
        version = self.version
        xmlns = self.xmlns

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id is not UNSET:
            field_dict["id"] = id
        if channel_name is not UNSET:
            field_dict["channelName"] = channel_name
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if transport is not UNSET:
            field_dict["Transport"] = transport
        if video is not UNSET:
            field_dict["Video"] = video
        if audio is not UNSET:
            field_dict["Audio"] = audio
        if enable_cabac is not UNSET:
            field_dict["enableCABAC"] = enable_cabac
        if sub_stream_rec_status is not UNSET:
            field_dict["subStreamRecStatus"] = sub_stream_rec_status
        if custom_stream_enable is not UNSET:
            field_dict["customStreamEnable"] = custom_stream_enable
        if version is not UNSET:
            field_dict["@version"] = version
        if xmlns is not UNSET:
            field_dict["@xmlns"] = xmlns

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_audio import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_video import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo,
        )

        d = src_dict.copy()
        id = d.pop("id", UNSET)

        channel_name = d.pop("channelName", UNSET)

        enabled = d.pop("enabled", UNSET)

        _transport = d.pop("Transport", UNSET)
        transport: Union[
            Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport
        ]
        if isinstance(_transport, Unset):
            transport = UNSET
        else:
            transport = (
                RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransport.from_dict(
                    _transport
                )
            )

        _video = d.pop("Video", UNSET)
        video: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo]
        if isinstance(_video, Unset):
            video = UNSET
        else:
            video = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelVideo.from_dict(
                _video
            )

        _audio = d.pop("Audio", UNSET)
        audio: Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio]
        if isinstance(_audio, Unset):
            audio = UNSET
        else:
            audio = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelAudio.from_dict(
                _audio
            )

        enable_cabac = d.pop("enableCABAC", UNSET)

        sub_stream_rec_status = d.pop("subStreamRecStatus", UNSET)

        custom_stream_enable = d.pop("customStreamEnable", UNSET)

        version = d.pop("@version", UNSET)

        xmlns = d.pop("@xmlns", UNSET)

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel = cls(
            id=id,
            channel_name=channel_name,
            enabled=enabled,
            transport=transport,
            video=video,
            audio=audio,
            enable_cabac=enable_cabac,
            sub_stream_rec_status=sub_stream_rec_status,
            custom_stream_enable=custom_stream_enable,
            version=version,
            xmlns=xmlns,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info_fec_dest_port_no import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecDestPortNo,
    )
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info_fec_ratio import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecRatio,
    )


T = TypeVar(
    "T",
    bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfo",
)


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfo:
    """
    Attributes:
        fec_ratio (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTranspor
            tMulticastFecInfoFecRatio]):
        fec_dest_port_no (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelT
            ransportMulticastFecInfoFecDestPortNo]):
    """

    fec_ratio: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecRatio",
    ] = UNSET
    fec_dest_port_no: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecDestPortNo",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        fec_ratio: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fec_ratio, Unset):
            fec_ratio = self.fec_ratio.to_dict()

        fec_dest_port_no: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.fec_dest_port_no, Unset):
            fec_dest_port_no = self.fec_dest_port_no.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if fec_ratio is not UNSET:
            field_dict["fecRatio"] = fec_ratio
        if fec_dest_port_no is not UNSET:
            field_dict["fecDestPortNo"] = fec_dest_port_no

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info_fec_dest_port_no import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecDestPortNo,
        )
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info_fec_ratio import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecRatio,
        )

        d = src_dict.copy()
        _fec_ratio = d.pop("fecRatio", UNSET)
        fec_ratio: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecRatio,
        ]
        if isinstance(_fec_ratio, Unset):
            fec_ratio = UNSET
        else:
            fec_ratio = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecRatio.from_dict(
                _fec_ratio
            )

        _fec_dest_port_no = d.pop("fecDestPortNo", UNSET)
        fec_dest_port_no: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecDestPortNo,
        ]
        if isinstance(_fec_dest_port_no, Unset):
            fec_dest_port_no = UNSET
        else:
            fec_dest_port_no = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportMulticastFecInfoFecDestPortNo.from_dict(
                _fec_dest_port_no
            )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info = cls(
            fec_ratio=fec_ratio,
            fec_dest_port_no=fec_dest_port_no,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_multicast_fec_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door import (
        RootTypeForXMLCapRemoteControlDoorRemoteControlDoor,
    )


T = TypeVar("T", bound="RootTypeForXMLCapRemoteControlDoor")


@attr.s(auto_attribs=True)
class RootTypeForXMLCapRemoteControlDoor:
    """RemoteControlDoor capability message in XML format

    Example:
        {'RemoteControlDoor': {'@version': '2.0', '@xmlns': 'http://www.isapi.org/ver20/XMLSchema', 'doorNo': {'@min':
            '', '@max': ''}, 'cmd': {'@opt': 'open,close,alwaysOpen,alwaysClose,visitorCallLadder,householdCallLadder'},
            'password': {'@min': '', '@max': ''}}}

    Attributes:
        remote_control_door (Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoor]):
    """

    remote_control_door: Union[Unset, "RootTypeForXMLCapRemoteControlDoorRemoteControlDoor"] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        remote_control_door: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.remote_control_door, Unset):
            remote_control_door = self.remote_control_door.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if remote_control_door is not UNSET:
            field_dict["RemoteControlDoor"] = remote_control_door

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_cap_remote_control_door_remote_control_door import (
            RootTypeForXMLCapRemoteControlDoorRemoteControlDoor,
        )

        d = src_dict.copy()
        _remote_control_door = d.pop("RemoteControlDoor", UNSET)
        remote_control_door: Union[Unset, RootTypeForXMLCapRemoteControlDoorRemoteControlDoor]
        if isinstance(_remote_control_door, Unset):
            remote_control_door = UNSET
        else:
            remote_control_door = RootTypeForXMLCapRemoteControlDoorRemoteControlDoor.from_dict(_remote_control_door)

        root_type_for_xml_cap_remote_control_door = cls(
            remote_control_door=remote_control_door,
        )

        root_type_for_xml_cap_remote_control_door.additional_properties = d
        return root_type_for_xml_cap_remote_control_door

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list_control_protocol_streaming_transport import (
        RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport,
    )


T = TypeVar("T", bound="RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocol")


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocol:
    """
    Attributes:
        streaming_transport (Union[Unset,
            RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport]):
    """

    streaming_transport: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        streaming_transport: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.streaming_transport, Unset):
            streaming_transport = self.streaming_transport.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if streaming_transport is not UNSET:
            field_dict["streamingTransport"] = streaming_transport

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list_control_protocol_streaming_transport import (
            RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport,
        )

        d = src_dict.copy()
        _streaming_transport = d.pop("streamingTransport", UNSET)
        streaming_transport: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport,
        ]
        if isinstance(_streaming_transport, Unset):
            streaming_transport = UNSET
        else:
            streaming_transport = RootTypeForXMLStreamingChannelStreamingChannelTransportControlProtocolListControlProtocolStreamingTransport.from_dict(
                _streaming_transport
            )

        root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list_control_protocol = cls(
            streaming_transport=streaming_transport,
        )

        root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list_control_protocol.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_transport_control_protocol_list_control_protocol

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['hikvision_isapi_cli',
 'hikvision_isapi_cli.api',
 'hikvision_isapi_cli.api.default',
 'hikvision_isapi_cli.api.isapi',
 'hikvision_isapi_cli.models',
 'hikvision_isapi_sk']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.15.4,<0.24.0',
 'pytest-asyncio>=0.20.3',
 'pytest-socket>=0.5.1',
 'pytest>=7.2.0',
 'python-dateutil>=2.8.0,<3.0.0',
 'xmltodict>=0.13.0']

setup_kwargs = {
    'name': 'hikvision-isapi-cli',
    'version': '1.0.11',
    'description': 'A client library for accessing Hikvision ISAPI',
    'long_description': '# hikvision-isapi-cli\nA client library for accessing Hikvision ISAPI\n\n### OpenAPI Generator\n\n```bash\nrm -fr .history/;cd ..;openapi-python-client update --path hikvision-isapi-cli/openapi.json --custom-template-path=hikvision-isapi-cli/templates/ --config=hikvision-isapi-cli/.config.yaml;cd hikvision-isapi-cli\n```\n\n## Usage\nFirst, create a client:\n\n```python\nfrom hikvision_isapi_cli import Client\n\nclient = Client(base_url="https://api.example.com", username="username", password="SuperSecretPassword")\n```\n\nNow call your endpoint and use your models:\n\n```python\nfrom hikvision_isapi_cli.models import MyDataModel\nfrom hikvision_isapi_cli.api.my_tag import get_my_data_model\nfrom hikvision_isapi_cli.types import Response\n\nmy_data: MyDataModel = get_my_data_model.sync(client=client)\n# or if you need more info (e.g. status_code)\nresponse: Response[MyDataModel] = get_my_data_model.sync_detailed(client=client)\n```\n\nOr do the same thing with an async version:\n\n```python\nfrom hikvision_isapi_cli.models import MyDataModel\nfrom hikvision_isapi_cli.api.my_tag import get_my_data_model\nfrom hikvision_isapi_cli.types import Response\n\nmy_data: MyDataModel = await get_my_data_model.asyncio(client=client)\nresponse: Response[MyDataModel] = await get_my_data_model.asyncio_detailed(client=client)\n```\n\nBy default, when you\'re calling an HTTPS API it will attempt to verify that SSL is working correctly. Using certificate verification is highly recommended most of the time, but sometimes you may need to authenticate to a server (especially an internal server) using a custom certificate bundle.\n\n```python\nclient = Client(\n    base_url="https://internal_api.example.com", \n    verify_ssl="/path/to/certificate_bundle.pem",\n)\n```\n\nYou can also disable certificate validation altogether, but beware that **this is a security risk**.\n\n```python\nclient = Client(\n    base_url="https://internal_api.example.com",  \n    verify_ssl=False\n)\n```\n\nThere are more settings on the generated `Client` class which let you control more runtime behavior, check out the docstring on that class for more info.\n\nThings to know:\n1. Every path/method combo becomes a Python module with four functions:\n    1. `sync`: Blocking request that returns parsed data (if successful) or `None`\n    1. `sync_detailed`: Blocking request that always returns a `Request`, optionally with `parsed` set if the request was successful.\n    1. `asyncio`: Like `sync` but async instead of blocking\n    1. `asyncio_detailed`: Like `sync_detailed` but async instead of blocking\n\n1. All path/query params, and bodies become method arguments.\n1. If your endpoint had any tags on it, the first tag will be used as a module name for the function (my_tag above)\n1. Any endpoint which did not have a tag will be in `hikvision_isapi_cli.api.default`\n\n## Building / publishing this Client\nThis project uses [Poetry](https://python-poetry.org/) to manage dependencies  and packaging.  Here are the basics:\n1. Update the metadata in pyproject.toml (e.g. authors, version)\n1. If you\'re using a private repository, configure it with Poetry\n    1. `poetry config repositories.<your-repository-name> <url-to-your-repository>`\n    1. `poetry config http-basic.<your-repository-name> <username> <password>`\n1. Publish the client with `poetry publish --build -r <your-repository-name>` or, if for public PyPI, just `poetry publish --build`\n\nIf you want to install this client into another project without publishing it (e.g. for development) then:\n1. If that project **is using Poetry**, you can simply do `poetry add <path-to-this-client>` from that project\n1. If that project is not using Poetry:\n    1. Build a wheel with `poetry build -f wheel`\n    1. Install that wheel from the other project `pip install <path-to-wheel>`\n',
    'author': 'mmascia',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_security_security_algorithm import (
        RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecuritySecurityAlgorithm,
    )


T = TypeVar(
    "T", bound="RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecurity"
)


@attr.s(auto_attribs=True)
class RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecurity:
    """
    Attributes:
        enabled (Union[Unset, str]):
        certificate_type (Union[Unset, str]):
        security_algorithm (Union[Unset, RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChanne
            lTransportSecuritySecurityAlgorithm]):
    """

    enabled: Union[Unset, str] = UNSET
    certificate_type: Union[Unset, str] = UNSET
    security_algorithm: Union[
        Unset,
        "RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecuritySecurityAlgorithm",
    ] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        enabled = self.enabled
        certificate_type = self.certificate_type
        security_algorithm: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.security_algorithm, Unset):
            security_algorithm = self.security_algorithm.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if certificate_type is not UNSET:
            field_dict["certificateType"] = certificate_type
        if security_algorithm is not UNSET:
            field_dict["SecurityAlgorithm"] = security_algorithm

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_security_security_algorithm import (
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecuritySecurityAlgorithm,
        )

        d = src_dict.copy()
        enabled = d.pop("enabled", UNSET)

        certificate_type = d.pop("certificateType", UNSET)

        _security_algorithm = d.pop("SecurityAlgorithm", UNSET)
        security_algorithm: Union[
            Unset,
            RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecuritySecurityAlgorithm,
        ]
        if isinstance(_security_algorithm, Unset):
            security_algorithm = UNSET
        else:
            security_algorithm = RootTypeForXMLStreamingChannelStreamingChannelCustomStreamEnableStreamingChannelTransportSecuritySecurityAlgorithm.from_dict(
                _security_algorithm
            )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_security = cls(
            enabled=enabled,
            certificate_type=certificate_type,
            security_algorithm=security_algorithm,
        )

        root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_security.additional_properties = (
            d
        )
        return root_type_for_xml_streaming_channel_streaming_channel_custom_stream_enable_streaming_channel_transport_security

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
